#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/funambol-update.sh - paramater update script
#
# Creation   : 2010-02-16 richter
# Last update: $Id: funambol-update.sh 99 2010-02-16 17:39:46Z christian $
#
# Copyright (c) 2010 christian richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/funambol-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=funambol

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_FUNAMBOL='no'
FUNAMBOL_DOWNLOAD='yes'
FUNAMBOL_DOWNLOAD_URL='http://download.forge.objectweb.org/sync4j'
FUNAMBOL_ARCHIVE='funambol-8.2.5.tgz'
FUNAMBOL_INSTALL_PATH='/usr/local/funambol'
FUNAMBOL_URL='localhost'
FUNAMBOL_LISTEN_PORT='8080'
FUNAMBOL_ADMIN='admin'
FUNAMBOL_ADMIN_EMAIL='admin@funambol.com'
FUNAMBOL_ADMIN_PASS='sa'
FUNAMBOL_DB='funambol'
FUNAMBOL_DB_USER='funambol'
FUNAMBOL_DB_PASS='funambol'
FUNAMBOL_PUSH_PORT='4745'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2010-02-16" "richter"
    # ------------------------------------------------------------------------


    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_FUNAMBOL" "Use: yes or no"
    printvar "FUNAMBOL_DOWNLOAD" "Do you want to download funambol: yes or no"
    printvar "FUNAMBOL_DOWNLOAD_URL" "enter here the full path"
    printvar "FUNAMBOL_ARCHIVE" "Name of archive"
    printvar "FUNAMBOL_INSTALL_PATH" "Where do you want to install funambol?"
    printvar "FUNAMBOL_URL" "On which URL you want to listen funambol?"
    printvar "FUNAMBOL_LISTEN_PORT" "On wich port does funambol listen?"
    printvar "FUNAMBOL_PUSH_PORT" "Portnumber of push-service"
    printvar "FUNAMBOL_ADMIN" "DON'T CHANGE! Username of funambol admin"
    printvar "FUNAMBOL_ADMIN_EMAIL" "Email adress of the admin"
    printvar "FUNAMBOL_ADMIN_PASS" "Password of funambol admin"
    printvar "FUNAMBOL_DB" "Name of mysql database"
    printvar "FUNAMBOL_DB_USER" "User of funambol database"
    printvar "FUNAMBOL_DB_PASS" "Password of database user"
    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
    printgpl -check ${packageName} '2010-02-16' 'richter' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG
# Variable              OPT_VARIABLE         VARIABLE_N          VALUE
START_FUNAMBOL          -                    -                   YESNO
FUNAMBOL_DOWNLOAD       START_FUNAMBOL       -                   YESNO
FUNAMBOL_DOWNLOAD_URL   FUNAMBOL_DOWNLOAD    -                   ENOBLANK
FUNAMBOL_ARCHIVE        FUNAMBOL_DOWNLOAD    -                   ENOBLANK
FUNAMBOL_INSTALL_PATH   FUNAMBOL_DOWNLOAD    -                   ABS_PATH
FUNAMBOL_URL            START_FUNAMBOL       -                   ENOBLANK
FUNAMBOL_LISTEN_PORT    START_FUNAMBOL       -                   PORT
FUNAMBOL_PUSH_PORT      START_FUNAMBOL       -                   PORT
FUNAMBOL_ADMIN          START_FUNAMBOL       -                   READONLY
FUNAMBOL_ADMIN_EMAIL    START_FUNAMBOL       -                   MAILADDR
FUNAMBOL_ADMIN_PASS     START_FUNAMBOL       -                   PASSWD
FUNAMBOL_DB             START_FUNAMBOL       -                   NOBLANK
FUNAMBOL_DB_USER        START_FUNAMBOL       -                   NOBLANK
FUNAMBOL_DB_PASS        START_FUNAMBOL       -                   PASSWD
EOFG

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${packageName}
    chown root /etc/check.d/${packageName}

#    printgpl -check_exp ${packageName} '2010-02-16' 'richter' >/etc/check.d/${packageName}.exp
#    cat >> /etc/check.d/${packageName}.exp <<EOFG
#
#EOFG

    # Set rights for check.exp file
#    chmod 0600 /etc/check.d/${packageName}.exp
#    chown root /etc/check.d/${packageName}.exp

#    printgpl -check_ext ${packageName} '2010-02-16' 'richter' >/etc/check.d/${packageName}.ext
#    cat >> /etc/check.d/${packageName}.ext <<EOFG
#
#
#EOFG

    # Set rights for check.ext file
#    chmod 0600 /etc/check.d/${packageName}.ext
#    chown root /etc/check.d/${packageName}.ext
}



# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/${packageName} ]
then
    mecho -info -n "Updating configuration."
else
    mecho -info -n "Creating configuration."
fi

makeConfigFile /etc/default.d/${packageName}

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info " Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
