#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/funambol - FUNAMBOL configuration
#
# Creation   : 2010-02-16 richter
# Last update: $Id: funambol.sh 99 2010-02-26 17:39:46Z christian $
#
# Copyright (c) 2010 christian richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/funambol-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# include config
configFile="/etc/config.d/funambol"
. ${configFile}

# set package name
packageName=funambol

# Variablen deklarieren
DATABASE='mysql'
packagePath="${FUNAMBOL_INSTALL_PATH}"
mkdir -p ${packagePath}
jdbcClasspath="${packagePath}/mysql-connector-java-5.0.8-bin.jar"
jdbcDriver="com.mysql.jdbc.Driver"
jdbcUrl="jdbc:mysql://localhost/${FUNAMBOL_DB}?characterEncoding=UTF-8"
jdbcUser="${FUNAMBOL_DB_USER}"
jdbcPassword="${FUNAMBOL_DB_PASS}"
FunambolInstallProperties="${packagePath}/Funambol/ds-server/install.properties"
CTPServerConfiguration="${packagePath}/Funambol/config/com/funambol/ctp/server/CTPServerConfiguration.xml"
InboxListenerConfiguration="${packagePath}/Funambol/config/com/funambol/email/inboxlistener/InboxListenerConfiguration.xml"
PIMListenerConfiguration="${packagePath}/Funambol/config/com/funambol/pimlistener/PIMListenerConfiguration.xml"
ServerConfig="${packagePath}/Funambol/tools/tomcat/conf/server.xml"
FunambolStartScript="${packagePath}/Funambol/bin/funambol"

# Position fr Start/Stop festlegen
# Mit dier Loesung brauch ich nur die Startposition festlegen,
# Stopposition wird automatisch berechnet.
package_pos='30'
package_kill_pos=`/usr/bin/expr 100 - ${package_pos}`
if [ $package_kill_pos -lt 10 ]
then
    package_kill_pos='0'${package_kill_pos}
fi
package_start='S'${package_pos}${packageName}
package_kill='K'${package_kill_pos}${packageName}


# ============================================================================
# Funktionen
# ============================================================================

# ----------------------------------------------------------------------------
# Download des Funambol-Archivs
# ----------------------------------------------------------------------------
checkDiskSpace () {
    diskSpace=`df -k ${packagePath} | tail -n -1 | awk '{if ( $4 ~ /%/) { print $3 } else { print $4 } }'`
    if [ $diskSpace -lt $diskSpaceRequired ]; then
        mecho -warn "You will need atleast ${diskSpaceRequired} kBytes of Disk Free\n" $diskSpaceRequired
        mecho -warn "Please free up the required Disk Space and try again\n"
        exit 3
    fi
}

download_funambol () {
    if [ "${START_FUNAMBOL}" == "yes" ] && [ "${FUNAMBOL_DOWNLOAD}" == "yes" ]
    then
        ToBeConinued='true'
        if [ -d "${packagePath}/Funambol" ]
        then
            mecho "It seems to be an Funambol Server installed."
            mecho "Do you want to download the Package anyway?"
            mecho -warn "Note: All data will be lost!"
            mecho
            if /var/install/bin/ask "Do you want continue?" "no"
            then
                # ------------------------------------------------------------
                # Diese Variante zur ueberpruefung der PID (bis zu 120 Stueck)
                # ist zwar ganz schoen umstaendlich aber es funktioniert
                # Dank an Olaf Jaehrling der das so geloest hat.
                pid=`ps -ef | grep -v grep| grep -v init| grep -v menu| grep funambol | awk -F" " {'print $2'}`
                if [ -n "${pid}" ]
                then
                    sh /etc/init.d/funambol stop >/dev/null
                fi
                ToBeConinued='true'
                rm -rf ${packagePath}/Funambol
            else
                ToBeConinued='false'
                downloaded='true'
            fi
        fi
        if [ "${ToBeConinued}" == "true" ]
        then
            cd ${packagePath}
            diskSpaceRequired=400000
            checkDiskSpace
            mecho
            mecho -info "Please wait while downloading the source."
            mecho
            wget ${FUNAMBOL_DOWNLOAD_URL}/${FUNAMBOL_ARCHIVE}
            tar -xzvf ${FUNAMBOL_ARCHIVE}
            rm -f ${FUNAMBOL_ARCHIVE}
            chown -R root:root *
            downloaded='true'
        fi
        if [ "${downloaded}" == "true" ]
        then
            _funambol_config_tmpfile=`mktemp -t funambol_configFile.XXXXXXXXXX`
            sed "s/^FUNAMBOL_DOWNLOAD=.*/FUNAMBOL_DOWNLOAD='no'/" ${configFile} >${_funambol_config_tmpfile}
            mv ${_funambol_config_tmpfile} ${configFile}
            chmod 0600 ${configFile}
        fi
    fi
}

# ----------------------------------------------------------------------------
# MySQL Datenbank
# ----------------------------------------------------------------------------
mysql_basedir='/usr/local/mysql'
mysqld_get_param() {
        ${mysql_basedir}/bin/mysqld --print-defaults \
                | tr " " "\n" \
                | grep -- "--$1" \
                | tail -n 1 \
                | cut -d= -f2
}

# Diese Funktion ist eigentlich obsolet, bleibt aber erst mal drin,
# frisst ja kein Brot ;-)
checkDatabase() {
            /var/install/bin/check-package -p mysql "FUNAMBOL_DATABASE='mysql'"
            retvar="${?}"
            if [ "${retvar}" -eq 0 ]
            then
                mysql_pidfile=`mysqld_get_param pid-file`
                mysql_datadir=`mysqld_get_param datadir`
            else
                #mecho -warn "Package mysql not installed, so we use default"
                mecho -warn "Sorry, package mysql not istalled, you can't start funambol"
            echo
                # set parameter from 'yes' to 'no'
                _funambol_config_tmpfile=`mktemp -t funambol_configFile.XXXXXXXXXX`
                sed "s/^START_FUNAMBOL=.*/START_FUNAMBOL='no'/" ${configFile} >${_funambol_config_tmpfile}
                mv ${_funambol_config_tmpfile} ${configFile}
                chmod 0600 ${configFile}
                START_FUNAMBOL='no'
            fi
}

MySQL_helper() {
    if [ -f "${mysql_pidfile}" ]
    then
        if [ -f ${mysql_datadir}/backup.pwd ]
        then
            passwd=`grep passwd= ${mysql_datadir}/backup.pwd | sed 's/passwd=//'`
            helper='true'
        fi
    fi
}

createDATABASEandUSER() {
    mecho "Creating mysql database '${FUNAMBOL_DB}' and mysql user '${FUNAMBOL_DB_USER}'."
    mecho
    mysql -u backup -p${passwd} -e "GRANT ALL PRIVILEGES ON ${FUNAMBOL_DB}.* TO '${FUNAMBOL_DB_USER}'@'localhost' IDENTIFIED BY '${FUNAMBOL_DB_PASS}'; "
    mysql -u backup -p${passwd} -e "CREATE DATABASE IF NOT EXISTS ${FUNAMBOL_DB};"

}

# ----------------------------------------------------------------------------
# CTPServerConfiguration.xml
# ----------------------------------------------------------------------------
WriteCTPServerConfiguration() {
    if [ -f "${CTPServerConfiguration}" ]
    then
        cat > ${_funambol_CTPServer_Configuration} <<EOFG
<?xml version="1.0" encoding="UTF-8"?>
<java version="1.4.2" class="java.beans.XMLDecoder">
    <object class="com.funambol.ctp.server.config.CTPServerConfigBean">

        <!--
            The port number
        -->
        <void property="portNumber">
            <int>${FUNAMBOL_PUSH_PORT}</int>
        </void>

        <!--
            The number of threads used for processing incoming connections.
            If the value is 0 then (availableProcessors + 1) is used.
            Must be greater than or equal to 0.
        -->
        <void property="connectionAcceptorThreadPoolSize">
            <int>0</int>
        </void>

        <!--
            Max elapsed idle time allowed in milliseconds.
            0 means that an infinite time is allowed (in seconds)
        -->
        <void property="clientHeartBeatExpectedTime">
            <int>900</int>
        </void>

        <!--
            The name of the JGroups configuration file used to configure the group
            between the ctp-servers and the ctp-senders
        -->
        <void property="notificationGroupConfigFileName">
            <string>jgroups-ctp-notification-group.xml</string>
        </void>

        <!--
            The name of the JGroups channel between the ctp-servers and the ctp-senders
        -->
        <void property="notificationGroupName">
            <string>ctp-notification-group</string>
        </void>

        <!--
            Should the logging filter be enabled?
        -->
        <void property="loggingFilterEnabled">
            <boolean>false</boolean>
        </void>

        <!--
            The ds-server web service access details
        -->
        <void property="WSServerInformation">
            <object class="com.funambol.server.admin.ws.client.ServerInformation">
                <void property="url">
                    <string>http://${FUNAMBOL_URL}:${FUNAMBOL_LISTEN_PORT}/funambol/services/admin</string>
                </void>
                <void property="username">
                    <string>${FUNAMBOL_ADMIN}</string>
                </void>
                <void property="password">
                    <string>${FUNAMBOL_ADMIN_PASS}</string>
                </void>
            </object>
        </void>

        <!--
            The AuthenticationManager
        -->
        <void property="authenticationManager">
            <string>com/funambol/ctp/server/authentication/AuthenticationManager.xml</string>
        </void>

        <!--
            Max authentication attempts allowed
        -->
        <void property="maxAuthenticationRetries">
            <int>2</int>
        </void>

        <!--
            The PendingNotificationManager
        -->
        <void property="pendingNotificationManager">
            <string>com/funambol/ctp/server/pending/PendingNotificationManager.xml</string>
        </void>

        <!--
            How often does Mina notify the ctp-server
            for idle connections? (in seconds)
        -->
        <void property="minaIdleTime">
            <int>60</int>
        </void>

        <!--
            The size of the buffer used by mina to read the data sent by the client
        -->
        <void property="receiveBufferSize">
            <int>64</int>
        </void>

        <!--
            Max expected connections
        -->
        <void property="maxConnections">
            <int>100000</int>
        </void>

        <!--
            Defines a cluster with name ctpserver using the file jgroups-ctp-server-group.xml
            located in the config directory
        -->
        <void property="clusterConfiguration">
            <object class="com.funambol.framework.cluster.ClusterConfiguration">
                <void property="clusterName">
                    <string>ctpserver</string>
                </void>
                <void property="configurationFile">
                    <string>jgroups-ctpserver.xml</string>
                </void>
            </object>
        </void>

    </object>
</java>

EOFG
        mv ${_funambol_CTPServer_Configuration} ${CTPServerConfiguration}
    fi
}
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# InboxListenerConfiguration.xml
# ----------------------------------------------------------------------------
WriteInboxListenerConfiguartiuon() {
    if [ -f "${InboxListenerConfiguration}" ]
    then
        cat > ${_funambol_InboxListener_Configuration} <<EOFG
<?xml version="1.0" encoding="UTF-8"?>
<java version="1.4.2" class="java.beans.XMLDecoder">
    <object class="com.funambol.pushlistener.service.config.PushListenerConfigBean">

        <void property="maxThreadPoolSize">
            <int>50</int>
        </void>

        <void property="healthThreadPollingTime">
            <!-- 10 minutes -->
            <long>600000</long>
        </void>

        <void property="registryMonitorPollingTime">
            <!-- 1 minute -->
            <long>60000</long>
        </void>

        <void property="taskPeriodTolerance">
            <double>0.1</double>
        </void>

        <void property="registryTableName">
            <string>fnbl_email_push_registry</string>
        </void>

        <void property="registryEntriesIdSpace">
            <string>email.registryid</string>
        </void>

        <void property="pluginDirectory">
            <string>com/funambol/email/inboxlistener/plugin</string>
        </void>

        <void property="serverInformation">
            <object class="com.funambol.server.admin.ws.client.ServerInformation">
                <void property="url">
                    <string>http://${FUNAMBOL_URL}:${FUNAMBOL_LISTEN_PORT}/funambol/services/admin</string>
                </void>
                <void property="username">
                    <string>${FUNAMBOL_ADMIN}</string>
                </void>
                <void property="password">
                    <string>${FUNAMBOL_ADMIN_PASS}</string>
                </void>
            </object>
        </void>

        <!--
            Defines a cluster with name inboxlistener using the file jgroups.xml
            under config directory
        -->
        <void property="clusterConfiguration">
            <object class="com.funambol.framework.cluster.ClusterConfiguration">
                <void property="clusterName">
                    <string>inboxlistener</string>
                </void>
                <void property="configurationFile">
                    <string>jgroups-inboxlistener.xml</string>
                </void>
            </object>
        </void>

    </object>
</java>

EOFG
        mv ${_funambol_InboxListener_Configuration} ${InboxListenerConfiguration}
    fi
}
# ---------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# PIMListenerConfiguration.xml
# ----------------------------------------------------------------------------
WritePIMListenerConfiguration() {
    if [ -f "${PIMListenerConfiguration}" ]
    then
        cat > ${_funambol_PIMListener_Configuration} <<EOFG
<?xml version="1.0" encoding="UTF-8"?>
<java version="1.4.2" class="java.beans.XMLDecoder">
    <object class="com.funambol.pushlistener.service.config.PushListenerConfigBean">

        <void property="maxThreadPoolSize">
            <int>50</int>
        </void>

        <void property="healthThreadPollingTime">
            <!-- values expressed in milliseconds -->
            <long>600000</long>
        </void>

        <void property="registryMonitorPollingTime">
            <!-- values expressed in milliseconds -->
            <long>60000</long>
        </void>

        <void property="taskPeriodTolerance">
            <double>0.1</double>
        </void>

        <void property="registryTableName">
            <string>fnbl_push_listener_registry</string>
        </void>

        <void property="registryEntriesIdSpace">
            <string>pushlistener.id</string>
        </void>

        <void property="pluginDirectory">
            <string>com/funambol/pimlistener/plugin</string>
        </void>

        <void property="ServerInformation">
            <object class="com.funambol.server.admin.ws.client.ServerInformation">
                <void property="url">
                    <string>http://${FUNAMBOL_URL}:${FUNAMBOL_LISTEN_PORT}/funambol/services/admin</string>
                </void>
                <void property="username">
                    <string>${FUNAMBOL_ADMIN}</string>
                </void>
                <void property="password">
                    <string>${FUNAMBOL_ADMIN_PASS}</string>
                </void>
            </object>
        </void>

        <!--
            Defines a cluster with name pimlistener using the file jgroups-pimlistener.xml
            under config directory
        -->
        <void property="clusterConfiguration">
            <object class="com.funambol.framework.cluster.ClusterConfiguration">
                <void property="clusterName">
                    <string>pimlistener</string>
                </void>
                <void property="configurationFile">
                    <string>jgroups-pimlistener.xml</string>
                </void>
            </object>
        </void>

    </object>
</java>

EOFG
        mv ${_funambol_PIMListener_Configuration} ${PIMListenerConfiguration}
    fi
}    
# ---------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# server.xml
# ----------------------------------------------------------------------------
WriteServerXML() {
    if [ -f "${ServerConfig}" ]
    then
        cat > ${_funambol_ServerConfig} <<EOFG
<?xml version='1.0' encoding='utf-8'?>
<!--
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
  this work for additional information regarding copyright ownership.
  The ASF licenses this file to You under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with
  the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
-->
<!-- Note:  A "Server" is not itself a "Container", so you may not
     define subcomponents such as "Valves" at this level.
     Documentation at /docs/config/server.html
 -->
<Server port="8005" shutdown="SHUTDOWN">

  <!--APR library loader. Documentation at /docs/apr.html -->
  <Listener className="org.apache.catalina.core.AprLifecycleListener" SSLEngine="on" />
  <!--Initialize Jasper prior to webapps are loaded. Documentation at /docs/jasper-howto.html -->
  <Listener className="org.apache.catalina.core.JasperListener" />
  <!-- JMX Support for the Tomcat server. Documentation at /docs/non-existent.html -->
  <Listener className="org.apache.catalina.mbeans.ServerLifecycleListener" />
  <Listener className="org.apache.catalina.mbeans.GlobalResourcesLifecycleListener" />

  <!-- Global JNDI resources
       Documentation at /docs/jndi-resources-howto.html
  -->
  <GlobalNamingResources>
    <!-- Editable user database that can also be used by
         UserDatabaseRealm to authenticate users
    -->
    <Resource name="UserDatabase" auth="Container"
              type="org.apache.catalina.UserDatabase"
              description="User database that can be updated and saved"
              factory="org.apache.catalina.users.MemoryUserDatabaseFactory"
              pathname="conf/tomcat-users.xml" />
  </GlobalNamingResources>

  <!-- A "Service" is a collection of one or more "Connectors" that share
       a single "Container" Note:  A "Service" is not itself a "Container",
       so you may not define subcomponents such as "Valves" at this level.
       Documentation at /docs/config/service.html
   -->
  <Service name="Catalina">

    <!--The connectors can use a shared executor, you can define one or more named thread pools-->
    <!--
    <Executor name="tomcatThreadPool" namePrefix="catalina-exec-"
        maxThreads="150" minSpareThreads="4"/>
    -->


    <!-- A "Connector" represents an endpoint by which requests are received
         and responses are returned. Documentation at :
         Java HTTP Connector: /docs/config/http.html (blocking & non-blocking)
         Java AJP  Connector: /docs/config/ajp.html
         APR (HTTP/AJP) Connector: /docs/apr.html
         Define a non-SSL HTTP/1.1 Connector on port 8080
    -->
    <!-- Funambol comment: don't modify or remove this Funambol comment! ##### -->
    <Connector port="${FUNAMBOL_LISTEN_PORT}" protocol="HTTP/1.1"
               connectionTimeout="20000"
               redirectPort="8443" />
    <!-- Funambol comment: don't modify or remove this Funambol comment! ###### -->
    <!-- A "Connector" using the shared thread pool-->
    <!--
    <Connector executor="tomcatThreadPool"
               port="${FUNAMBOL_LISTEN_PORT}" protocol="HTTP/1.1"
               connectionTimeout="20000"
               redirectPort="8443" />
    -->
    <!-- Define a SSL HTTP/1.1 Connector on port 8443
         This connector uses the JSSE configuration, when using APR, the
         connector should be using the OpenSSL style configuration
         described in the APR documentation -->
    <!--
    <Connector port="8443" protocol="HTTP/1.1" SSLEnabled="true"
               maxThreads="150" scheme="https" secure="true"
               clientAuth="false" sslProtocol="TLS" />
    -->

    <!-- Define an AJP 1.3 Connector on port 8009 -->
    <Connector port="8009" protocol="AJP/1.3" redirectPort="8443" />


    <!-- An Engine represents the entry point (within Catalina) that processes
         every request.  The Engine implementation for Tomcat stand alone
         analyzes the HTTP headers included with the request, and passes them
         on to the appropriate Host (virtual host).
         Documentation at /docs/config/engine.html -->

    <!-- You should set jvmRoute to support load-balancing via AJP ie :
    <Engine name="Standalone" defaultHost="localhost" jvmRoute="jvm1">
    -->
    <Engine name="Catalina" defaultHost="localhost">

      <!--For clustering, please take a look at documentation at:
          /docs/cluster-howto.html  (simple how to)
          /docs/config/cluster.html (reference documentation) -->
      <!--
      <Cluster className="org.apache.catalina.ha.tcp.SimpleTcpCluster"/>
      -->

      <!-- The request dumper valve dumps useful debugging information about
           the request and response data received and sent by Tomcat.
           Documentation at: /docs/config/valve.html -->
      <!--
      <Valve className="org.apache.catalina.valves.RequestDumperValve"/>
      -->

      <!-- This Realm uses the UserDatabase configured in the global JNDI
           resources under the key "UserDatabase".  Any edits
           that are performed against this UserDatabase are immediately
           available for use by the Realm.  -->
      <Realm className="org.apache.catalina.realm.UserDatabaseRealm"
             resourceName="UserDatabase"/>

      <!-- Define the default virtual host
           Note: XML Schema validation will not work with Xerces 2.2.
       -->
      <Host name="localhost"  appBase="webapps"
            unpackWARs="true" autoDeploy="true"
            xmlValidation="false" xmlNamespaceAware="false">

        <!-- SingleSignOn valve, share authentication between web applications
             Documentation at: /docs/config/valve.html -->
        <!--
        <Valve className="org.apache.catalina.authenticator.SingleSignOn" />
        -->

        <!-- Access log processes all example.
             Documentation at: /docs/config/valve.html -->
        <!--
        <Valve className="org.apache.catalina.valves.AccessLogValve" directory="logs"
               prefix="localhost_access_log." suffix=".txt" pattern="common" resolveHosts="false"/>
        -->

      </Host>
    </Engine>
  </Service>
</Server>

EOFG
        mv ${_funambol_ServerConfig} ${ServerConfig}
    fi
}
# ---------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Change admin password and email
# ----------------------------------------------------------------------------
ChangeAdminPassAndEmail() {
    if [ -d "${packagePath/Funambol}" ]
    then
        cp /var/lib/funambol/pw-encrypter-0.0.1-SNAPSHOT.jar ${packagePath}/pw-encrypter-0.0.1-SNAPSHOT.jar
        pass=`java -jar ${packagePath}/pw-encrypter-0.0.1-SNAPSHOT.jar -e ${FUNAMBOL_ADMIN_PASS}`
        #echo ${pass}
        mysql -u ${FUNAMBOL_DB_USER} --password=${FUNAMBOL_DB_PASS} -e "USE ${FUNAMBOL_DB}; UPDATE fnbl_user SET password = '${pass}', email = '${FUNAMBOL_ADMIN_EMAIL}' WHERE username = 'admin';"
    fi
}
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# FunambolInstallProperties
# ----------------------------------------------------------------------------
InstallProperties() {
    if [ -d "${packagePath}/Funambol" ]
    then
        sed -e "s|^dbms=.*|dbms=${DATABASE}|" ${FunambolInstallProperties} \
            -e "s|^jdbc.classpath=.*|jdbc.classpath=${jdbcClasspath}|" \
            -e "s|^jdbc.driver=.*|jdbc.driver=${jdbcDriver}|" \
            -e "s|^jdbc.url=.*|jdbc.url=${jdbcUrl}|" \
            -e "s|^jdbc.user=.*|jdbc.user=${jdbcUser}|" \
            -e "s|^jdbc.password=.*|jdbc.password=${jdbcPassword}|" >${_funambol_InstallProperties}
        mv ${_funambol_InstallProperties} ${FunambolInstallProperties}
        MySQL_helper
        if [ "${helper}" == 'true' ]
        then
            if DBS=`mysql -u backup -h localhost -p${passwd} -Bse 'show databases' | grep ${FUNAMBOL_DB}`
            then
                mecho -info "Database already installed."
            else
                createDATABASEandUSER
                clrhome
                mecho -info "Please confirm all questions with 'yes'."
                mecho
                sh ${packagePath}/Funambol/bin/install
            fi
        fi
    fi
}
# ----------------------------------------------------------------------------


# ============================================================================
# Main
# ============================================================================
download_funambol
checkDatabase
# ----------------------------------------------------------------------------
# Hack fr die aktuelle Version v0.1.1
# Folgende Variablen sollen ueber die Konfiguration nicht geaendert werden,
# deshalb werden sie hier auf die Standardwerte gesetzt.
# Mit ECE ist eine Aenderung nicht moeglich, da READONLY
# Falls mit Joe oder aehnlich geaendert, werden hier die Variablen wieder
# auf die Standardwerte gesetzt.
if [ "${FUNAMBOL_ADMIN}" != "admin" ]
then
    _funambol_config_tmpfile=`mktemp -t funambol_configFile.XXXXXXXXXX`
    sed "s/^FUNAMBOL_ADMIN=.*/FUNAMBOL_ADMIN='admin'/" ${configFile} >${_funambol_config_tmpfile}
    mv ${_funambol_config_tmpfile} ${configFile}
    chmod 0600 ${configFile}
    FUNAMBOL_ADMIN='admin'
    mecho -warn "The variable 'FUNAMBOL_ADMIN' could not be changed!"
    mecho -warn "It was set to 'admin'."
    mecho
fi
# ----------------------------------------------------------------------------

# Symlinks setzen und bentigte Dateien kopieren
if [ -d "${packagePath}/Funambol" ]
then
    ln -sf ${packagePath}/Funambol/LICENSE.txt /usr/share/doc/funambol/LICENSE.txt
    jrePath=`ls ${packagePath}/Funambol/tools | grep jr*`
    ln -sf ${packagePath}/Funambol/tools/${jrePath}/jre/lib/tools.jar ${JAVA_HOME}/lib/tools.jar
    cp /var/lib/${packageName}/mysql-connector-java-5.0.8-bin.jar ${packagePath}/mysql-connector-java-5.0.8-bin.jar

    _funambol_InstallProperties=`mktemp -t funambol_InstallProperties.XXXXXXXXXX`
    _funambol_CTPServer_Configuration=`mktemp -t funambol_CTPServer_Config.XXXXXXXXXX`
    _funambol_InboxListener_Configuration=`mktemp -t funambol_InboxListener_Config.XXXXXXXXXX`
    _funambol_PIMListener_Configuration=`mktemp -t funambol_PIMListener_Config.XXXXXXXXXX`
    _funambol_ServerConfig=`mktemp -t funambol_Server_Config.XXXXXXXXXX`
fi

WriteCTPServerConfiguration
WriteInboxListenerConfiguartiuon
WritePIMListenerConfiguration
WriteServerXML
InstallProperties
ChangeAdminPassAndEmail

# Angepasstes Startscript kopieren
if [ -d "${packagePath/Funambol}" ]
then
    cp /var/lib/funambol/funambol_startscript ${FunambolStartScript}
    chmod 0755 ${configFile}
fi

# ----------------------------------------------------------------------------
# Generate symbolic links start/stop
# Hab ich hier so geloest, da Funambol leider immer wieder (warum auch immer)
# beim Serverneustart mitgestartet ist, obwohl in der Config ausgestellt.
# ----------------------------------------------------------------------------
case "${START_FUNAMBOL}" in
    yes)
        ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_start}
        ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}
    ;;
    no)
        rm -f /etc/rc2.d/${package_start}
        rm -f /etc/rc2.d/${package_kill}
    ;;
esac

exit 0
# ============================================================================
# End
# ============================================================================
